pub struct State(/* private fields */);Expand description
Type-safe heterogeneous state container.
Stores values keyed by their TypeId, allowing type-safe insertion and retrieval.
Used for dependency injection and cross-procedure shared state.
Follows rspc’s State pattern with NoOpHasher optimization.
Implementations
Sourceimpl State
impl State
pub fn new() -> Self
Sourcepub fn insert<T: Send + Sync + 'static>(&mut self, value: T)
pub fn insert<T: Send + Sync + 'static>(&mut self, value: T)
Insert a value. Replaces any existing value of the same type.
Sourcepub fn get<T: Send + Sync + 'static>(&self) -> Option<&T>
pub fn get<T: Send + Sync + 'static>(&self) -> Option<&T>
Get a reference to a stored value by type.
Sourcepub fn get_mut<T: Send + Sync + 'static>(&mut self) -> Option<&mut T>
pub fn get_mut<T: Send + Sync + 'static>(&mut self) -> Option<&mut T>
Get a mutable reference to a stored value by type.